@@ -8,11 +8,13 @@ import jsii
 import jsii.compat
 import publication
 
+import aws_cdk.assets._jsii
 import aws_cdk.aws_cloudwatch._jsii
 import aws_cdk.aws_iam._jsii
 import aws_cdk.aws_kms._jsii
 import aws_cdk.aws_logs._jsii
 import aws_cdk.aws_s3._jsii
+import aws_cdk.aws_s3_assets._jsii
 import aws_cdk.aws_ssm._jsii
 import aws_cdk.cloud_assembly_schema._jsii
 import aws_cdk.core._jsii
@@ -21,7 +23,7 @@ import aws_cdk.region_info._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-cdk/aws-ec2", "1.58.0", __name__[0:-6], "aws-ec2@1.58.0.jsii.tgz"
+    "@aws-cdk/aws-ec2", "1.60.0", __name__[0:-6], "aws-ec2@1.60.0.jsii.tgz"
 )
 
 __all__ = [
